"""
Type annotations for boto3.dynamodb.types module.

Copyright 2024 Vlad Emelianov
"""

from decimal import Context
from typing import Any, Literal, Mapping, Sequence, TypedDict

class _AttributeValueTypeDef(TypedDict, total=False):
    S: str
    N: str
    B: bytes
    SS: Sequence[str]
    NS: Sequence[str]
    BS: Sequence[bytes]
    M: Mapping[str, Any]
    L: Sequence[Any]
    NULL: bool
    BOOL: bool

STRING: Literal["S"]
NUMBER: Literal["N"]
BINARY: Literal["B"]
STRING_SET: Literal["SS"]
NUMBER_SET: Literal["NS"]
BINARY_SET: Literal["BS"]
NULL: Literal["NULL"]
BOOLEAN: Literal["BOOL"]
MAP: Literal["M"]
LIST: Literal["L"]

DYNAMODB_CONTEXT: Context

BINARY_TYPES: tuple[Any, ...]

class Binary:
    def __init__(self, value: Any) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __bytes__(self) -> str: ...
    def __hash__(self) -> int: ...

class TypeSerializer:
    def serialize(self, value: Any) -> _AttributeValueTypeDef: ...

class TypeDeserializer:
    def deserialize(self, value: _AttributeValueTypeDef) -> Any: ...



"""
Type annotations for boto3.compat module.

Copyright 2024 Vlad Emelianov
"""

import os
from typing import Any

SOCKET_ERROR: type[ConnectionError]

rename_file = os.rename

def filter_python_deprecation_warnings() -> None: ...
def is_append_mode(fileobj: Any) -> bool: ...



"""
Type annotations for boto3.ec2.createtags module.

Copyright 2024 Vlad Emelianov
"""

from typing import Any, Iterable

def inject_create_tags(
    event_name: str, class_attributes: dict[str, Any], **kwargs: Any
) -> None: ...
def create_tags(self: Any, **kwargs: Iterable[Any]) -> list[dict[str, Any]]: ...



"""
Type annotations for boto3.docs.attr module.

Copyright 2024 Vlad Emelianov
"""

from boto3.resources.model import Identifier
from botocore.docs.bcdoc.restdoc import DocumentStructure
from botocore.docs.params import ResponseParamsDocumenter
from botocore.hooks import BaseEventHooks
from botocore.model import Shape

class ResourceShapeDocumenter(ResponseParamsDocumenter):
    EVENT_NAME: str

def document_attribute(
    section: DocumentStructure,
    service_name: str,
    resource_name: str,
    attr_name: str,
    event_emitter: BaseEventHooks,
    attr_model: Shape,
    include_signature: bool = True,
) -> None: ...
def document_identifier(
    section: DocumentStructure,
    resource_name: str,
    identifier_model: Identifier,
    include_signature: bool = ...,
) -> None: ...
def document_reference(
    section: DocumentStructure, reference_model: Shape, include_signature: bool = ...
) -> None: ...



"""
Type annotations for boto3.resources.factory module.

Copyright 2024 Vlad Emelianov
"""

import logging
from typing import Any

from boto3.resources.base import ServiceResource
from boto3.utils import ServiceContext
from botocore.hooks import BaseEventHooks

logger: logging.Logger

class ResourceFactory:
    def __init__(self, emitter: BaseEventHooks) -> None: ...
    def load_from_definition(
        self,
        resource_name: str,
        single_resource_json_definition: dict[str, Any],
        service_context: ServiceContext,
    ) -> type[ServiceResource]: ...
